==> jc-1.4.0.tar.gz: jasmin/InsnInfo.h <==
// class jasmin.InsnInfo

// class file dependencies
// @dep_class 153cace9869e0e97 jasmin_InsnInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_InsnInfo_H_
#define _JC_jasmin_InsnInfo_H_

// Forward structure declarations
struct _jc_jasmin_InsnInfo$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_jasmin_InsnInfo$sub_refs	_jc_jasmin_InsnInfo$sub_refs;
typedef struct _jc_jasmin_InsnInfo$sub_nonrefs	_jc_jasmin_InsnInfo$sub_nonrefs;
typedef struct _jc_jasmin_InsnInfo$refs	_jc_jasmin_InsnInfo$refs;
typedef struct _jc_jasmin_InsnInfo$nonrefs	_jc_jasmin_InsnInfo$nonrefs;
typedef struct _jc_jasmin_InsnInfo$object	_jc_jasmin_InsnInfo$object;

typedef struct _jc_jasmin_InsnInfo$fields_struct	_jc_jasmin_InsnInfo$fields_struct;
typedef const struct _jc_jasmin_InsnInfo$vmethods	_jc_jasmin_InsnInfo$vmethods;
typedef const struct _jc_jasmin_InsnInfo$vtable	_jc_jasmin_InsnInfo$vtable;
typedef const struct _jc_jasmin_InsnInfo$vtype	_jc_jasmin_InsnInfo$vtype;

// Class fields structure
struct _jc_jasmin_InsnInfo$fields_struct {
	struct _jc_java_util_Hashtable$object	*infoTable;
};
extern _jc_jasmin_InsnInfo$fields_struct _jc_jasmin_InsnInfo$class_fields;

// Constructors
extern void _jc_jasmin_InsnInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_InsnInfo$object *);

// Static methods
extern void _jc_jasmin_InsnInfo$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_jasmin_InsnInfo$method$addInfo$6cff63b151ef94f2(_jc_env *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *);
extern jboolean _jc_jasmin_InsnInfo$method$contains$14daef07ea176c5a(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_jasmin_InsnInfo$object *_jc_jasmin_InsnInfo$method$get$4f3f8a7fdf5435f7(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_jasmin_InsnInfo$vmethods {
};

// Vtable
struct _jc_jasmin_InsnInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_InsnInfo$vmethods	jasmin_InsnInfo;
};

// Vtype
struct _jc_jasmin_InsnInfo$vtype {
	_jc_type			type;
	_jc_jasmin_InsnInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_InsnInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*args;
};

// Reference instance fields (object)
struct _jc_jasmin_InsnInfo$refs {
    _jc_jasmin_InsnInfo$sub_refs	jasmin_InsnInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_InsnInfo$sub_nonrefs {
	jint	opcode;
};

// Non-reference instance fields (object)
struct _jc_jasmin_InsnInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_InsnInfo$sub_nonrefs	jasmin_InsnInfo;
};

// Object instance structure
struct _jc_jasmin_InsnInfo$object {
	_jc_jasmin_InsnInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_InsnInfo$vtype	*vtype;
	_jc_jasmin_InsnInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_InsnInfo$vtype _jc_jasmin_InsnInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_InsnInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_InsnInfo$class_object;

#endif	/* _JC_jasmin_InsnInfo_H_ */

==> jc-1.4.6.tar.gz: jasmin/InsnInfo.h <==
// class jasmin.InsnInfo

// class file dependencies
// @dep_class 153cace9869e0e97 jasmin_InsnInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_InsnInfo_H_
#define _JC_jasmin_InsnInfo_H_

// Forward structure declarations
struct _jc_jasmin_InsnInfo$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_jasmin_InsnInfo$sub_refs	_jc_jasmin_InsnInfo$sub_refs;
typedef struct _jc_jasmin_InsnInfo$sub_nonrefs	_jc_jasmin_InsnInfo$sub_nonrefs;
typedef struct _jc_jasmin_InsnInfo$refs	_jc_jasmin_InsnInfo$refs;
typedef struct _jc_jasmin_InsnInfo$nonrefs	_jc_jasmin_InsnInfo$nonrefs;
typedef struct _jc_jasmin_InsnInfo$object	_jc_jasmin_InsnInfo$object;

typedef struct _jc_jasmin_InsnInfo$fields_struct	_jc_jasmin_InsnInfo$fields_struct;
typedef const struct _jc_jasmin_InsnInfo$vmethods	_jc_jasmin_InsnInfo$vmethods;
typedef const struct _jc_jasmin_InsnInfo$vtable	_jc_jasmin_InsnInfo$vtable;
typedef const struct _jc_jasmin_InsnInfo$vtype	_jc_jasmin_InsnInfo$vtype;

// Class fields structure
struct _jc_jasmin_InsnInfo$fields_struct {
	struct _jc_java_util_Hashtable$object	*infoTable;
};
extern _jc_jasmin_InsnInfo$fields_struct _jc_jasmin_InsnInfo$class_fields;

// Constructors
extern void _jc_jasmin_InsnInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_InsnInfo$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_jasmin_InsnInfo$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_jasmin_InsnInfo$method$addInfo$6cff63b151ef94f2(_jc_env *, struct _jc_java_lang_String$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_jasmin_InsnInfo$method$contains$14daef07ea176c5a(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_jasmin_InsnInfo$object *_jc_jasmin_InsnInfo$method$get$4f3f8a7fdf5435f7(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jasmin_InsnInfo$vmethods {
};

// Vtable
struct _jc_jasmin_InsnInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_InsnInfo$vmethods	jasmin_InsnInfo;
};

// Vtype
struct _jc_jasmin_InsnInfo$vtype {
	_jc_type			type;
	_jc_jasmin_InsnInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_InsnInfo$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*args;
};

// Reference instance fields (object)
struct _jc_jasmin_InsnInfo$refs {
    _jc_jasmin_InsnInfo$sub_refs	jasmin_InsnInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_InsnInfo$sub_nonrefs {
	jint	opcode;
};

// Non-reference instance fields (object)
struct _jc_jasmin_InsnInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_InsnInfo$sub_nonrefs	jasmin_InsnInfo;
};

// Object instance structure
struct _jc_jasmin_InsnInfo$object {
	_jc_jasmin_InsnInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_InsnInfo$vtype	*vtype;
	_jc_jasmin_InsnInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_InsnInfo$vtype _jc_jasmin_InsnInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_InsnInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_InsnInfo$class_object;

#endif	/* _JC_jasmin_InsnInfo_H_ */
